# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - ApproveChanges library

    @copyright: 2011 by Paul Boddie <paul@boddie.org.uk>
    @license: GNU GPL (v2 or later), see COPYING.txt for details.
"""

import re

__version__ = "0.1"

def get_queued_changes_area(request):
    return getattr(request.cfg, "queued_changes_area", "ApprovalQueue")

def get_approved_editors_group(request):
    return getattr(request.cfg, "approved_editors_group", "ApprovedGroup")

def match_queue_pages(pagename, queued_changes_area):

    "Return a filter function which matches subpages of 'pagename'."

    return re.compile(ur"^%s/%s/.*$" % (re.escape(pagename), re.escape(queued_changes_area)), re.UNICODE).match

def get_queue_pages(request, pagename, queued_changes_area):

    """
    Return the queued pages given the 'request', 'pagename' and subpage folder
    specified by 'queued_changes_area'.
    """

    return request.rootpage.getPageList(exists=1, filter=match_queue_pages(pagename, queued_changes_area))

def is_queued_page(pagename, queued_changes_area):

    """
    Return whether 'pagename' is a queued page by testing for the presence of
    the 'queued_changes_area' component in its page path.
    """

    parts = pagename.split("/")
    return len(parts) > 2 and parts[-2] == queued_changes_area

def get_target_page_name(pagename):

    "Return the target page name for the given queued 'pagename'."

    return "/".join(pagename.split("/")[:-2])

# Utility classes and associated functions.
# NOTE: These are a subset of EventAggregatorSupport.

class Form:

    """
    A wrapper preserving MoinMoin 1.8.x (and earlier) behaviour in a 1.9.x
    environment.
    """

    def __init__(self, form):
        self.form = form

    def get(self, name, default=None):
        values = self.form.getlist(name)
        if not values:
            return default
        else:
            return values

    def __getitem__(self, name):
        return self.form.getlist(name)

class ActionSupport:

    """
    Work around disruptive MoinMoin changes in 1.9, and also provide useful
    convenience methods.
    """

    def get_form(self):
        return get_form(self.request)

def get_form(request):

    "Work around disruptive MoinMoin changes in 1.9."

    if hasattr(request, "values"):
        return Form(request.values)
    else:
        return request.form

# vim: tabstop=4 expandtab shiftwidth=4
